<?php
/*
Plugin Name: G4 Analytics Plugin by Inzinc Media
Description: Adds Google Analytics 4 (G4) tag to the footer of all pages.
*/

// Add a custom menu item for the plugin settings page
function g4_analytics_add_menu() {
    add_options_page('G4 Analytics Plugin Settings', 'G4 Analytics', 'manage_options', 'g4-analytics-settings', 'g4_analytics_settings_page');
}
add_action('admin_menu', 'g4_analytics_add_menu');

// Register and display the plugin settings page
function g4_analytics_settings_page() {
    ?>
    <div class="wrap">
        <h1>G4 Analytics Plugin Settings</h1>
        <form method="post" action="options.php">
            <?php settings_fields('g4-analytics-settings-group'); ?>
            <?php do_settings_sections('g4-analytics-settings-group'); ?>
            <table class="form-table">
                <tr valign="top">
                    <th scope="row">G4 Measurement ID</th>
                    <td><input type="text" name="g4_measurement_id" value="<?php echo esc_attr(get_option('g4_measurement_id')); ?>" /></td>
                </tr>
            </table>
            <?php submit_button(); ?>
        </form>
    </div>
    <?php
}

// Register the plugin settings
function g4_analytics_register_settings() {
    register_setting('g4-analytics-settings-group', 'g4_measurement_id');
}
add_action('admin_init', 'g4_analytics_register_settings');

// Add the G4 tag to the footer of all pages
function g4_analytics_footer_script() {
    $g4_measurement_id = get_option('g4_measurement_id');

    if (!empty($g4_measurement_id)) {
        ?>
        <script async src="https://www.googletagmanager.com/gtag/js?id=<?php echo esc_attr($g4_measurement_id); ?>"></script>
        <script>
            window.dataLayer = window.dataLayer || [];
            function gtag(){dataLayer.push(arguments);}
            gtag('js', new Date());

            gtag('config', '<?php echo esc_attr($g4_measurement_id); ?>');
        </script>
        <?php
    }
}
add_action('wp_footer', 'g4_analytics_footer_script');
